==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/AccessPolicyConstraints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.KnowledgeConstraint;
import com.okta.sdk.resource.model.PossessionConstraint;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AccessPolicyConstraints
 */
@JsonPropertyOrder({ AccessPolicyConstraints.JSON_PROPERTY_KNOWLEDGE,
        AccessPolicyConstraints.JSON_PROPERTY_POSSESSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class AccessPolicyConstraints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_KNOWLEDGE = "knowledge";
    private KnowledgeConstraint knowledge;

    public static final String JSON_PROPERTY_POSSESSION = "possession";
    private PossessionConstraint possession;

    public AccessPolicyConstraints() {
    }

    public AccessPolicyConstraints knowledge(KnowledgeConstraint knowledge) {

        this.knowledge = knowledge;
        return this;
    }

    /**
     * Get knowledge
     *
     * @return knowledge
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_KNOWLEDGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public KnowledgeConstraint getKnowledge() {
        return knowledge;
    }

    @JsonProperty(JSON_PROPERTY_KNOWLEDGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKnowledge(KnowledgeConstraint knowledge) {
        this.knowledge = knowledge;
    }

    public AccessPolicyConstraints possession(PossessionConstraint possession) {

        this.possession = possession;
        return this;
    }

    /**
     * Get possession
     *
     * @return possession
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POSSESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PossessionConstraint getPossession() {
        return possession;
    }

    @JsonProperty(JSON_PROPERTY_POSSESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPossession(PossessionConstraint possession) {
        this.possession = possession;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AccessPolicyConstraints accessPolicyConstraints = (AccessPolicyConstraints) o;
        return Objects.equals(this.knowledge, accessPolicyConstraints.knowledge)
                && Objects.equals(this.possession, accessPolicyConstraints.possession);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(knowledge, possession);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPolicyConstraints {\n");
        sb.append("    knowledge: ").append(toIndentedString(knowledge)).append("\n");
        sb.append("    possession: ").append(toIndentedString(possession)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/AccessPolicyConstraints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.KnowledgeConstraint;
import com.okta.sdk.resource.model.PossessionConstraint;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AccessPolicyConstraints
 */
@JsonPropertyOrder({ AccessPolicyConstraints.JSON_PROPERTY_KNOWLEDGE,
        AccessPolicyConstraints.JSON_PROPERTY_POSSESSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AccessPolicyConstraints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_KNOWLEDGE = "knowledge";
    private KnowledgeConstraint knowledge;

    public static final String JSON_PROPERTY_POSSESSION = "possession";
    private PossessionConstraint possession;

    public AccessPolicyConstraints() {
    }

    public AccessPolicyConstraints knowledge(KnowledgeConstraint knowledge) {

        this.knowledge = knowledge;
        return this;
    }

    /**
     * Get knowledge
     *
     * @return knowledge
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_KNOWLEDGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public KnowledgeConstraint getKnowledge() {
        return knowledge;
    }

    @JsonProperty(JSON_PROPERTY_KNOWLEDGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKnowledge(KnowledgeConstraint knowledge) {
        this.knowledge = knowledge;
    }

    public AccessPolicyConstraints possession(PossessionConstraint possession) {

        this.possession = possession;
        return this;
    }

    /**
     * Get possession
     *
     * @return possession
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POSSESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PossessionConstraint getPossession() {
        return possession;
    }

    @JsonProperty(JSON_PROPERTY_POSSESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPossession(PossessionConstraint possession) {
        this.possession = possession;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AccessPolicyConstraints accessPolicyConstraints = (AccessPolicyConstraints) o;
        return Objects.equals(this.knowledge, accessPolicyConstraints.knowledge)
                && Objects.equals(this.possession, accessPolicyConstraints.possession);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(knowledge, possession);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPolicyConstraints {\n");
        sb.append("    knowledge: ").append(toIndentedString(knowledge)).append("\n");
        sb.append("    possession: ").append(toIndentedString(possession)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
